==> ldaptor_0.0.26.tar.gz: ldaptor-0.0.26/ldaptor/protocols/ldap/autofill/posixAccount.py <==
from twisted.internet import defer
from twisted.python import failure
from ldaptor import numberalloc
from ldaptor.protocols.ldap import ldapsyntax

class AutofillException(Exception):
    pass

class ObjectMissingObjectClassException(AutofillException):
    """

    The LDAPEntry is missing an objectClass this autofiller needs to
    operate.

    """
    pass

class Autofill_posix: #TODO baseclass
    def __init__(self,
                 baseDN,
                 freeNumberGetter=numberalloc.getFreeNumber):
        self.baseDN = baseDN
        self.freeNumberGetter = freeNumberGetter

    def _cb_gotNumbers(self, r, ldapObject):
        uid, gid = r

        ok, val = uid
        if not ok:
            val.trap()
        ldapObject['uidNumber'] = [str(val)]

        ok, val = gid
        if not ok:
            val.trap()
        ldapObject['gidNumber'] = [str(val)]

    def start(self, ldapObject):
        assert 'objectClass' in ldapObject
        if 'posixAccount' not in ldapObject['objectClass']:
            raise ObjectMissingObjectClassException, ldapObject

        assert 'loginShell' not in ldapObject
        ldapObject['loginShell'] = ['/bin/sh']

        baseObject = ldapsyntax.LDAPEntry(client=ldapObject.client,
                                          dn=self.baseDN)
        d1 = self.freeNumberGetter(baseObject, 'uidNumber', min=1000)

        d2 = self.freeNumberGetter(baseObject, 'gidNumber', min=1000)

        d = defer.DeferredList([d1, d2], fireOnOneErrback=1)

        # silence the log
        d1.addErrback(lambda x:None)
        d2.addErrback(lambda x:None)

        d.addCallback(self._cb_gotNumbers, ldapObject)
        return d

    def notify(self, ldapObject, attributeType):
        pass

==> ldaptor-20.0.0rc1.tar.gz: ldaptor-20.0.0rc1/ldaptor/protocols/ldap/autofill/posixAccount.py <==
from twisted.internet import defer
from ldaptor import numberalloc
from ldaptor.protocols.ldap import ldapsyntax, autofill


class Autofill_posix:  # TODO baseclass
    def __init__(self,
                 baseDN,
                 freeNumberGetter=numberalloc.getFreeNumber):
        self.baseDN = baseDN
        self.freeNumberGetter = freeNumberGetter

    def _cb_gotNumbers(self, r, ldapObject):
        uid, gid = r

        ok, val = uid
        if not ok:
            val.trap()
        ldapObject['uidNumber'] = [str(val)]

        ok, val = gid
        if not ok:
            val.trap()
        ldapObject['gidNumber'] = [str(val)]

    def start(self, ldapObject):
        assert 'objectClass' in ldapObject
        if 'posixAccount' not in ldapObject['objectClass']:
            raise autofill.ObjectMissingObjectClassException(ldapObject)

        assert 'loginShell' not in ldapObject
        ldapObject['loginShell'] = ['/bin/sh']

        baseObject = ldapsyntax.LDAPEntry(client=ldapObject.client,
                                          dn=self.baseDN)
        d1 = self.freeNumberGetter(baseObject, 'uidNumber', min=1000)

        d2 = self.freeNumberGetter(baseObject, 'gidNumber', min=1000)

        d = defer.DeferredList([d1, d2], fireOnOneErrback=1)

        # silence the log
        d1.addErrback(lambda x: None)
        d2.addErrback(lambda x: None)

        d.addCallback(self._cb_gotNumbers, ldapObject)
        return d

    def notify(self, ldapObject, attributeType):
        pass
